@@ -1,3 +1,5 @@
+from base64 import b64encode
+
 import pytest
 
 from ..relay import extract_global_id
@@ -7,7 +9,9 @@ from ..relay import extract_global_id
     "id,expected",
     [
         ("slug", "slug"),
-        ("V29ya2Zsb3dTcGVjaWZpY2F0aW9uOmxpc3RlbmVpbnRyYWc=", "listeneintrag"),
+        ("V29ya2Zsb3c6bGlzdGVuZWludHJhZw==", "listeneintrag"),
+        ("b106", "b106"),
+        (b64encode(b"NonExistantModel:foobar"),) * 2,
     ],
 )
 def test_extract_global_id(id, expected):
