@@ -4,7 +4,6 @@ from functools import wraps
 from django.contrib.postgres.fields import ArrayField
 from django.contrib.postgres.indexes import GinIndex
 from django.db import models, transaction
-from django.db.models import Q
 from django.utils.functional import cached_property
 from localized_fields.fields import LocalizedField, LocalizedTextField
 from minio import S3Error
@@ -348,12 +347,12 @@ class Document(core_models.UUIDModel):
         For root documents, we want to look through the whole document, while
         for row documents only the table-local answer is wanted.
         """
+        if self.family != self:
+            answers = self.answers
+        else:
+            answers = Answer.objects.filter(document__family=self)
 
-        return (
-            Answer.objects.filter(Q(document=self) | Q(document__family=self))
-            .order_by("-modified_at")
-            .first()
-        )
+        return answers.order_by("-modified_at").first()
 
     @property
     def modified_content_at(self):
